package com.sun.corba.se.impl.resolver;

import java.io.IOException;
import java.io.FileNotFoundException;
import com.sun.corba.se.impl.orbutil.CorbaResourceUtil;
import java.io.FileInputStream;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Set;
import org.omg.CORBA.Object;
import java.util.Properties;
import java.io.File;
import com.sun.corba.se.spi.orb.ORB;
import com.sun.corba.se.spi.resolver.Resolver;

public class FileResolverImpl implements Resolver
{
    private ORB orb;
    private File file;
    private Properties savedProps;
    private long fileModified;
    
    public FileResolverImpl(ORB orb, File file) {
        this.fileModified = 0L;
        this.orb = orb;
        this.file = file;
        this.savedProps = new Properties();
    }
    
    public org.omg.CORBA.Object resolve(String key) {
        this.check();
        String property = this.savedProps.getProperty(key);
        if (property == null) {
            return null;
        }
        return this.orb.string_to_object(property);
    }
    
    public Set list() {
        this.check();
        HashSet<Object> set = new HashSet();
        Enumeration<Object> propertyNames = this.savedProps.propertyNames();
        while (propertyNames.hasMoreElements()) {
            set.add(propertyNames.nextElement());
        }
        return set;
    }
    
    private void check() {
        if (this.file == null) {
            return;
        }
        long lastModified = this.file.lastModified();
        if (lastModified > this.fileModified) {
            try {
                FileInputStream inStream = new FileInputStream(this.file);
                this.savedProps.clear();
                this.savedProps.load(inStream);
                inStream.close();
                this.fileModified = lastModified;
            }
            catch (FileNotFoundException ex) {
                System.err.println(CorbaResourceUtil.getText("bootstrap.filenotfound", this.file.getAbsolutePath()));
            }
            catch (IOException ex2) {
                System.err.println(CorbaResourceUtil.getText("bootstrap.exception", this.file.getAbsolutePath(), ex2.toString()));
            }
        }
        return;
    }
}
